// Copyright 2019 The Bazel Authors. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
package com.google.devtools.build.lib.bazel.repository.starlark;

import com.google.devtools.build.lib.events.ExtendedEventHandler.Postable;

/** Event reporting about the place where a Starlark repository rule was defined. */
public final class StarlarkRepositoryDefinitionLocationEvent implements Postable {

  private final String name;
  private final String definitionInformation;

  public StarlarkRepositoryDefinitionLocationEvent(String name, String definitionInformation) {
    this.name = name;
    this.definitionInformation = definitionInformation;
  }

  public String getName() {
    return name;
  }

  public String getDefinitionInformation() {
    return definitionInformation;
  }
}
